==> image-editor_1.0.11.orig.tar.xz: image-editor-1.0.11/libimageviewer/translations/libimageviewer_zh_HK.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_HK">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>圖片訊息</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>基本訊息</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>詳細訊息</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>添加到相冊</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>新建相冊</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>所有圖片</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>打開圖片</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>導出</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>從相冊中移除</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>沒有權限查看圖片</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>文件類型</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>修改日期</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>拍攝日期</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>曝光模式</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>曝光程序</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>曝光時間</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>閃光燈</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>光圈大小</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>焦距</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO感光度</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>最大光圈值</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>測光模式</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>白平衡</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>閃光燈補償</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>鏡頭型號</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>顏色空間</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>相機型號</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>圖片尺寸</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>標記</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>返回</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>上一張</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一張</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1視圖</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>適應窗口</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>識別文字</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆時針旋轉</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>順時針旋轉</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>退出全屏</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>打印</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>幻燈片放映</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>顯示導航窗口</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>隱藏導航窗口</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>設為壁紙</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>在檔案管理員中顯示</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>圖片訊息</translation>
    </message>
    <message>
        <source>day</source>
        <translation>天</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>確 定</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>請輸入圖片名稱</translation>
    </message>
    <message>
        <source>The file &quot;%1&quot; already exists, please use another name</source>
        <translation>檔名“%1”已被佔用，請使用其他名稱</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>上一張</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暫停</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一張</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>未發現圖片文件</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>未發現圖片文件</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation>沒有權限查看文件</translation>
    </message>
</context>
</TS>

==> image-editor_1.0.14.orig.tar.xz: image-editor-1.0.14/libimageviewer/translations/libimageviewer_zh_HK.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_HK">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>圖片訊息</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>基本訊息</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>詳細訊息</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>添加到相冊</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>新建相冊</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>所有圖片</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>打開圖片</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>導出</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>從相冊中移除</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>沒有權限查看圖片</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>文件類型</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>修改日期</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>拍攝日期</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>曝光模式</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>曝光程序</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>曝光時間</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>閃光燈</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>光圈大小</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>焦距</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO感光度</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>最大光圈值</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>測光模式</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>白平衡</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>閃光燈補償</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>鏡頭型號</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>顏色空間</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>相機型號</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>圖片尺寸</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>標記</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>返回</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>上一張</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一張</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1視圖</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>適應窗口</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>識別文字</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆時針旋轉</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>順時針旋轉</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>退出全屏</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>打印</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>幻燈片放映</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>顯示導航窗口</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>隱藏導航窗口</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>設為壁紙</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>在檔案管理員中顯示</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>圖片訊息</translation>
    </message>
    <message>
        <source>day</source>
        <translation>天</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>照片信息</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>確 定</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>請輸入圖片名稱</translation>
    </message>
    <message>
        <source>The file already exists, please use another name</source>
        <translation>文件名已被占用，請使用其他名稱</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>上一張</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暫停</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一張</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>未發現圖片文件</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>未發現圖片文件</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation>沒有權限查看文件</translation>
    </message>
</context>
</TS>
